@@ -155,16 +155,16 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
                 ctx.start_transaction().await.unwrap();
 
-                let result = ctx.get_checkout(&path_params.id).await.map_err(|err| Err(HttpError {
-                    status_code: StatusCode::BAD_REQUEST,
-                    error_code: Some(err.code.clone()),
-                    external_message: err.message.clone(),
-                    internal_message: err.message.clone(),
-                }));
+                let result = ctx.get_checkout(&path_params.id).await;
 
-                if let Err(_) = result {
+                if let Err(err) = result {
                     ctx.abort_transaction().await.unwrap();
-                    return result;
+                    return Err(HttpError {
+                        status_code: StatusCode::BAD_REQUEST,
+                        error_code: Some(err.code.clone()),
+                        external_message: err.message.clone(),
+                        internal_message: err.message.clone(),
+                    });
                 }
 
                 let maybe_co = result.unwrap();
